##  Modeling Guidelines for Meta Model v3
You can find the information on modeling guidelines for the Meta Model v3 here:
  * [Modeling Guidelines](https://help.sap.com/docs/leanix/ea/modeling-guidelines-v3?locale=en-US&state=PRODUCTION&version=CLOUD "In this section, we provide an overview of certain modeling guidelines within LeanIX. Our goal is to give you a clear idea of how to make use of LeanIX's structure and features in order to unlock its full potential.")
  * [Modeling: Application vs. IT component](https://help.sap.com/docs/leanix/ea/application-vs-it-component-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [Modeling: Objectives and Transformation Items (or Projects)](https://help.sap.com/docs/leanix/ea/objectives-and-transformations-items-v3?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [Modeling: Business Capabilities](https://help.sap.com/docs/leanix/ea/business-capabilities-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD "In this section, you will find a best-practice business capability model to upload into your workspace.")
  * [Modeling: Data Object](https://help.sap.com/docs/leanix/ea/data-object-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD "In this section, you will find a best practice Data Object model to upload to your workspace.")
  * [Modeling: Interfaces](https://help.sap.com/docs/leanix/ea/interfaces-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD "The Interface Fact Sheet addresses the Integration Architecture Management use case and can be used in combination with the Interface Circle Map and Data Flow Report.")
  * [Modeling: IT Components / Hosting](https://help.sap.com/docs/leanix/ea/it-components-hosting-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD "Modeling Application hosting is a common challenge for all enterprise architects. While it is possible to spend years discussing the perfect model that captures every single edge case, this section provides three step-by-step guides that we recommend and that can be applied based on your needs. There is an entry-level approach, a pragmatic one as well as the full-fledged option.")
  * [Modeling: Middleware and APIs](https://help.sap.com/docs/leanix/ea/middleware-and-apis-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD "In this section, you will find best practices for modeling middleware and APIs.")
  * [Modeling: Process](https://help.sap.com/docs/leanix/ea/process-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD "In this section, you will find best practices for modeling processes.")
  * [Modeling: Project](https://help.sap.com/docs/leanix/ea/project-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD "Measure the impact of projects on applications and domains, and see their suitability with your business strategy, using the Project Fact Sheets and Reports in LeanIX.")
  * [Modeling: Tech Category](https://help.sap.com/docs/leanix/ea/tech-category-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD "In this section, you will find a best practice Tech Category model to upload to your workspace.")
  * [Modeling: User Group](https://help.sap.com/docs/leanix/ea/user-group-modeling-v3?locale=en-US&state=PRODUCTION&version=CLOUD "The User Group Fact Sheet is an essential part of LeanIX's approach to representing business architecture. Often customers use it combined either with Business Capabilities or with Processes to obtain an Application Matrix report which is perfectly suited to identify possible synergies or gaps in the application landscape.")


YesNo
Send
